# Release Notes

---

## Upgrading

To upgrade `concave_hull` to the latest version, use pip:

```bash
pip install -U concave_hull
```

## Version 0.0.9 (2024-12-15)

*   Fix broken package (not well tested)

## Version 0.0.8 (2024-10-03)

*   Add typing stubs

## Version 0.0.7 (2024-01-06)

*   Strip useless code

## Version 0.0.6 (2023-04-05)

*   Integrate Grahams-Scan algorithm, drop scipy dependency

## Version 0.0.5 (2023-03-04)

*   Add macOS, Linux arm64 release
*   Supports WGS84 data, add `is_wgs84:bool=False` parameter

## Version 0.0.4 (2023-03-03)

*   Auto release to pypi

## Version 0.0.3 (2023-03-02)

*   Integrate scipy ConvexHull, add API: `concave_hull(points, *args, **kwargs)`

## Version 0.0.2 (2023-10-05)

*   First release to pypi

---

You can also checkout releases on:

-   GitHub: <https://github.com/cubao/concave_hull/releases>
-   PyPi: <https://pypi.org/project/concave-hull>
